<?php
/*
 * @package sixteen, Copyright Rohit Tripathi, rohitink.com
 * This file contains Custom Theme Related Functions.
 */
 
class Sixteen_Menu_With_Description extends Walker_Nav_Menu {
	function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0) {
		global $wp_query;
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		
		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		$class_names = ' class="' . esc_attr( $class_names ) . '"';

		$output .= $indent . '<li id="menu-item-'. $item->ID . '"' . $value . $class_names .'>';

		$fontIcon = ! empty( $item->attr_title ) ? ' <i class="fa ' . esc_attr( $item->attr_title ) .'">' : '';
		$attributes = ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) .'"' : '';
		$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) .'"' : '';
		$attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) .'"' : '';

		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>'.$fontIcon.'</i>';
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '<br /><span class="menu-desc">' . $item->description . '</span>';
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args, $id );
	}
}
//Supports Icon only. No Description.
class Sixteen_Menu_With_Icon extends Walker_Nav_Menu {
	function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0) {
		global $wp_query;
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		
		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		$class_names = ' class="' . esc_attr( $class_names ) . '"';

		$output .= $indent . '<li id="menu-item-'. $item->ID . '"' . $value . $class_names .'>';

		$fontIcon = ! empty( $item->attr_title ) ? ' <i class="fa ' . esc_attr( $item->attr_title ) .'">' : '';
		$attributes = ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) .'"' : '';
		$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) .'"' : '';
		$attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) .'"' : '';

		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>'.$fontIcon.'</i>';
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args, $id );
	}
}

/*
 * Pagination Function. Implements core paginate_links function.
 */
function sixteen_pagination() {
	global $wp_query;
	$big = 12345678;
	$page_format = paginate_links( array(
	    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	    'format' => '?paged=%#%',
	    'current' => max( 1, get_query_var('paged') ),
	    'total' => $wp_query->max_num_pages,
	    'type'  => 'array'
	) );
	if( is_array($page_format) ) {
	            $paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
	            echo '<div class="pagination"><div><ul>';
	            echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
	            foreach ( $page_format as $page ) {
	                    echo "<li>$page</li>";
	            }
	           echo '</ul></div></div>';
	 }
}
//Quick Fixes for Custom Post Types.
function sixteen_pagination_queried( $query ) {
	$big = 12345678;
	$page_format = paginate_links( array(
	    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	    'format' => '?paged=%#%',
	    'current' => max( 1, get_query_var('paged') ),
	    'total' => $query->max_num_pages,
	    'type'  => 'array'
	) );
	if( is_array($page_format) ) {
	            $paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
	            echo '<div class="pagination"><div><ul>';
	            echo '<li><span>'. $paged . ' of ' . $query->max_num_pages .'</span></li>';
	            foreach ( $page_format as $page ) {
	                    echo "<li>$page</li>";
	            }
	           echo '</ul></div></div>';
	 }
}

/*
** Favicon and Apple Touch Icon
*/
function sixteen_header_icons() {
	if ( get_theme_mod('sixteen_favicon') ) 
		echo "<link rel='shortcut icon' href='".get_theme_mod('sixteen_favicon')."' />";
	
	if ( get_theme_mod('sixteen_apple_icon') ) 	
		echo "<link rel='apple-touch-icon' href='".get_theme_mod('sixteen_apple_icon')."'>";
}
add_action('wp_head', 'sixteen_header_icons');

/*
** Customizer Controls 
*/
if (class_exists('WP_Customize_Control')) {
	class WP_Customize_Category_Control extends WP_Customize_Control {
        /**
         * Render the control's content.
         */
        public function render_content() {
            $dropdown = wp_dropdown_categories(
                array(
                    'name'              => '_customize-dropdown-categories-' . $this->id,
                    'echo'              => 0,
                    'show_option_none'  => __( '&mdash; Select &mdash;', 'sixteen' ),
                    'option_none_value' => '0',
                    'selected'          => $this->value(),
                )
            );
 
            $dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );
 
            printf(
                '<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
                $this->label,
                $dropdown
            );
        }
    }
}    
/*
** Function to check if Sidebar is enabled on Current Page 
*/
function sixteen_load_sidebar() {
	wp_reset_postdata();
	$load_sidebar = true;
	if ( get_theme_mod('sixteen_disable_sidebar') ) :
		$load_sidebar = false;
	elseif( get_theme_mod('sixteen_disable_sidebar_home') && is_home() )	:
		$load_sidebar = false;
	elseif( get_theme_mod('sixteen_disable_sidebar_front') && is_front_page() ) :
		$load_sidebar = false;
	elseif( get_theme_mod('sixteen_disable_sidebar_archive') && is_archive() ) :
		$load_sidebar = false;	
	elseif ( get_post_meta( get_the_ID(), 'enable-full-width', true ) )	:
		$load_sidebar = false;
	endif;
	
	return  $load_sidebar;
}

/*
**	Determining Sidebar and Primary Width
*/
function sixteen_primary_class() {
	$sw = get_theme_mod('sixteen_sidebar_width',4);
	$class = "col-md-".(12-$sw);
	
	wp_reset_postdata();
	if ( !sixteen_load_sidebar() ) 
		$class = "col-md-12";
	
	echo $class;
}
add_action('sixteen_primary-width', 'sixteen_primary_class');

function sixteen_secondary_class() {
	$sw = get_theme_mod('sixteen_sidebar_width',4);
	$class = "col-md-".$sw;
	
	echo $class;
}
add_action('sixteen_secondary-width', 'sixteen_secondary_class');


/*
**	Helper Function to Convert Colors
*/
function sixteen_hex2rgb($hex) {
   $hex = str_replace("#", "", $hex);
   if(strlen($hex) == 3) {
      $r = hexdec(substr($hex,0,1).substr($hex,0,1));
      $g = hexdec(substr($hex,1,1).substr($hex,1,1));
      $b = hexdec(substr($hex,2,1).substr($hex,2,1));
   } else {
      $r = hexdec(substr($hex,0,2));
      $g = hexdec(substr($hex,2,2));
      $b = hexdec(substr($hex,4,2));
   }
   $rgb = array($r, $g, $b);
   return implode(",", $rgb); // returns the rgb values separated by commas
   //return $rgb; // returns an array with the rgb values
}
function sixteen_fade($color, $val) {
	return "rgba(".sixteen_hex2rgb($color).",". $val.")";
}


/*
** Function to Get Theme Layout 
*/
function sixteen_get_blog_layout(){
	static $sixteen_post_count = 0;
	$ldir = 'framework/layouts/content';
	if (get_theme_mod('sixteen_blog_layout') ) :
		get_template_part( $ldir , get_theme_mod('sixteen_blog_layout') );
	else :
		get_template_part( $ldir ,'grid');	
	endif;	
}
add_action('sixteen_blog_layout', 'sixteen_get_blog_layout');

/*
** Function to Deal with Elements of Inequal Heights, Enclose them in a bootstrap row.
*/
function sixteen_open_div_row() {
	echo "<div class='row grid-row col-md-12'>";
}
function sixteen_close_div_row() {
	echo "</div><!--.grid-row-->";
}


function sixteen_before_article() {

	global $sixteen_post_count;
	$array_2_3_4 = array('grid_2_column',
							'grid_3_column',
							'grid_4_column',
							'photos_3_column',
							'photos_2_column',
							'box_4_column',							
							'templates/template-blog-grid3c.php',
							'templates/template-blog-grid2c.php', 
							'templates/template-blog-grid4c.php',
							'templates/template-blog-photos3c.php',
							'templates/template-blog-photos2c.php',
							'templates/template-blog-box4c.php'
						);
	//wp_reset_postdata();	- Don't Reset any Data, because we are not using get_post_meta	
	//See what the get_queried_object_id() function does. Though, the Query is reset in template files.			
	//For 2,3,4 Column Posts
	 $page_template = get_post_meta( get_queried_object_id(), '_wp_page_template', true );
	if ( in_array( get_theme_mod('sixteen_blog_layout'), $array_2_3_4 ) || in_array( $page_template, $array_2_3_4 ) ) : 
			 if ( $sixteen_post_count  == 0 ) {
			  	sixteen_open_div_row();
			  }
	endif;	  	
}
add_action('sixteen_before-article', 'sixteen_before_article');

/* Pre and Post Article Hooking */
function sixteen_after_article() {
	global $sixteen_post_count;
	//echo $sixteen_post_count;
	wp_reset_postdata();
	$template = get_post_meta( get_the_id(), '_wp_page_template', true );
	//For 3 Column Posts
	if (   ( get_theme_mod('sixteen_blog_layout') == 'grid_3_column' ) 
		|| ( get_theme_mod('sixteen_blog_layout') == 'photos_3_column' )
 		|| ( $template == 'templates/template-blog-grid3c.php' )
 		|| ( $template == 'templates/template-blog-photos3c.php' ) ):
		
		

		global $wp_query;
		if (($wp_query->current_post +1) == ($wp_query->post_count)) :
			 	sixteen_close_div_row();
		else :
			if ( ( $sixteen_post_count ) == 2 ) {
			 	sixteen_close_div_row();
				$sixteen_post_count = 0;
				}
			else {
				$sixteen_post_count++;
			}
		endif;		
		
	//For 2 Column Posts
	elseif ( ( get_theme_mod('sixteen_blog_layout') == 'grid_2_column' )
		|| ( get_theme_mod('sixteen_blog_layout') == 'photos_2_column' )
		|| ( $template == 'templates/template-blog-grid2c.php' )
		|| ( $template == 'templates/template-blog-photos2c.php' ) ):
		
		
		
		global $wp_query;
		if (($wp_query->current_post +1) == ($wp_query->post_count)) :
			 	sixteen_close_div_row();
			 	$sixteen_post_count = 0;
		else :
			if ( ( $sixteen_post_count ) == 1 ) {
			 	sixteen_close_div_row();
				$sixteen_post_count = 0;
				}
			else {
				$sixteen_post_count++;
			}
		endif;		
	
	//For 4 Columns
	elseif ( ( get_theme_mod('sixteen_blog_layout') == 'grid_4_column' )
		|| ( get_theme_mod('sixteen_blog_layout') == 'box_4_column' )
		|| ( $template == 'templates/template-blog-box4c.php' )
		|| ( $template == 'templates/template-blog-grid4c.php' ) ):
		
		
		
		global $wp_query;
		if (($wp_query->current_post +1) == ($wp_query->post_count)) :
			 	sixteen_close_div_row();
		else :
			if ( ( $sixteen_post_count ) == 3 ) {
			 	sixteen_close_div_row();
				$sixteen_post_count = 0;
				}
			else {
				$sixteen_post_count++;
			}
		endif;		
	endif;
	
}
add_action('sixteen_after-article', 'sixteen_after_article');

/*
** Function to check if Component is Enabled.
*/
function sixteen_is_enabled( $component ) {
	
	wp_reset_postdata();
	$return_val = false;
	
	switch ($component) {
		
		case 'slider' :
		
			if ( ( get_theme_mod('sixteen_main_slider_enable' ) && is_home() )
				||( get_post_meta( get_the_ID(), 'enable-slider', true ) ) ) :
					$return_val = true;
			endif;
			break;
		
		case 'fc1' :
		
			if ( ( get_theme_mod('sixteen_grid_enable') && is_home() )
				|| ( get_post_meta( get_the_ID(), 'enable-img-grid', true ) ) ) :
					$return_val = true;
				endif;
				break;
		
		case 'fc2' :
		
			 if ( ( get_theme_mod('sixteen_box_enable') && is_home() )
			 	|| ( get_post_meta( get_the_ID(), 'enable-sqbx', true ) ) ) : 
			 		$return_val = true;
			 	endif;
			 	break;		 		
									
	}//endswitch
	
	return $return_val;
	
}

/*
**   Display Slider
*/	
function sixteen_display_slider() {
	if  ( sixteen_is_enabled( 'slider' ) )
			get_template_part('slider', 'nivo' );
}
add_action('sixteen_before-mega-container', 'sixteen_display_slider');
/*
**	Hook Just before content. To Display Featured Content.
*/
function sixteen_display_fc() {
			
		if  ( sixteen_is_enabled( 'fc2' ) )	
			get_template_part('featured', 'content2');
		
		if  ( sixteen_is_enabled( 'fc1' ) )	
			get_template_part('featured', 'content1'); 
		
}
add_action('sixteen_before-content', 'sixteen_display_fc');


/*
** Sixteen Render Slider
*/
function sixteen_render_slider() {
	$sixteen_slider = array(
		'pager' => get_theme_mod('sixteen_slider_pager', true ),
		'animSpeed' => get_theme_mod('sixteen_slider_speed', 500 ),
		'pauseTime' => get_theme_mod('sixteen_slider_pause', 5000 ),
		'autoplay' => !get_theme_mod('sixteen_slider_autoplay', true ),
		'random' => get_theme_mod('sixteen_slider_random', false ),
		'effect' => get_theme_mod('sixteen_slider_effect', 'random' )
	);
	wp_localize_script( 'sixteen-custom-js', 'slider_object', $sixteen_slider );
}
add_action('wp_enqueue_scripts', 'sixteen_render_slider', 20);


/*
** Display Home page Title
*/
function sixteen_blog_title() {
	if (is_home()) {
		echo "<h1 class='page-title'>".get_theme_mod('sixteen_blog_title', 'Recent Posts')."</h1>";
	}
}
add_action('sixteen-after_main','sixteen_blog_title');

/*
** Load WooCommerce Compatibility FIle
*/
if ( class_exists('woocommerce') ) :
	require get_template_directory() . '/framework/woocommerce.php';
endif;


/*
** Load Custom Widgets
*/
require get_template_directory() . '/framework/widgets/recent-posts.php';
require get_template_directory() . '/framework/widgets/video.php';
require get_template_directory() . '/framework/widgets/featured-posts.php';
//require get_template_directory() . '/framework/widgets/facebook.php';
//require get_template_directory() . '/framework/widgets/gallery.php';

/**
 * Include Meta Boxes.
 */
require get_template_directory() . '/framework/metaboxes/page-attributes.php';
require get_template_directory() . '/framework/metaboxes/display-options.php';



