<?php
/*
** WooCommerce Compatibility File for sixteen Theme
** Created by Rohit Tripathi, Rohitink.com (c) 2015
** @package sixteen
*/

// Remove each style one by one
add_filter( 'woocommerce_enqueue_styles', 'sixteen_dequeue_woocommerce_styles' );
function sixteen_dequeue_woocommerce_styles( $enqueue_styles ) {
	unset( $enqueue_styles['woocommerce-general'] );	// Remove the gloss
	//unset( $enqueue_styles['woocommerce-layout'] );		// Remove the layout
	//unset( $enqueue_styles['woocommerce-smallscreen'] );	// Remove the smallscreen optimisation
	return $enqueue_styles;
}

/*
//Now included in main.css to make the process of making skins easier.
function sixteen_enqueue_woocommerce_style(){
	wp_register_style( 'sixteen-woocommerce-css', get_template_directory_uri() . '/assets/css/woocommerce.css' );
	
	if ( class_exists( 'woocommerce' ) ) {
		wp_enqueue_style( 'sixteen-woocommerce-css' );
	}
}
add_action( 'wp_enqueue_scripts', 'sixteen_enqueue_woocommerce_style' );
*/

//Custom Hooking for Product Loop Page Items.
function sixteen_before_wc_title() {
	echo "<div class='product-desc'>";
}
add_action('woocommerce_before_shop_loop_item_title', 'sixteen_before_wc_title', 15);

function sixteen_after_wc_title() {
	echo "</div>";
}
add_action('woocommerce_after_shop_loop_item_title', 'sixteen_after_wc_title');

/**
 * Remove the "shop" title on the main shop page
*/
function sixteen_woo_hide_page_title() {
	return false;
}
add_filter( 'woocommerce_show_page_title' , 'sixteen_woo_hide_page_title' );

/**
 * Change the Breadcrumb
*/
add_filter( 'woocommerce_breadcrumb_defaults', 'sixteen_change_breadcrumb_delimiter' );
function sixteen_change_breadcrumb_delimiter( $defaults ) {
	// Change the breadcrumb delimeter from '/' to '>>'
	$defaults['delimiter'] = ' <i class="fa fa-angle-right"></i> ';
	return $defaults;
}

/*
 * WooCommerce Output Wrappers for for Single Product(single-product.php) and Product Archives(archive-product.php)
 */
add_action('woocommerce_before_main_content', 'sixteen_single_custom_header', 1 );

function sixteen_single_custom_header() {
    if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>
        <div class="header-title col-md-12">
            <span><?php woocommerce_page_title(); ?></span>
        </div>
    <?php endif; ?>

    <div id="primary-mono" class="content-area <?php do_action('sixteen_primary-width') ?>">
        <main id="main" class="site-main" role="main">
    <?php
}

add_action( 'woocommerce_after_main_content', 'sixteen_single_custom_footer', 50 );

function sixteen_single_custom_footer() {
    echo "</main></div>";
}



/**
 * WooCommerce Extra Feature
 * --------------------------
 *
 * Change number of related products on product page
 * Set your own value for 'posts_per_page'
 *
 */ 
add_filter( 'woocommerce_output_related_products_args', 'sixteen_change_related_products_count' );

function sixteen_change_related_products_count( $args ) {
     $args['posts_per_page'] = 3;
     $args['columns'] = 3;

     return $args;
}

//Product Gallery Size 
function sixteen_gallery_four_columns(  ){
    return 4;
}
add_filter( 'woocommerce_product_thumbnails_columns', 'sixteen_gallery_four_columns');

// Change number or products per row to 3
add_filter('loop_shop_columns', 'loop_columns');
if (!function_exists('loop_columns')) {
	function loop_columns() {
		return 3; // 3 products per row
	}
}

// Ensure cart contents update when products are added to the cart via AJAX (place the following in functions.php)
add_filter( 'woocommerce_add_to_cart_fragments', 'sixteen_header_add_to_cart_fragment' );

function sixteen_header_add_to_cart_fragment( $fragments ) {
	ob_start();
	?>
			<a class="cart-contents" href="<?php echo WC()->cart->get_cart_url(); ?>" title="<?php _e('View your shopping cart', 'sixteen'); ?>">
						<div class="count"><?php echo sprintf(_n('%d item', '%d items', WC()->cart->cart_contents_count, 'sixteen'), WC()->cart->cart_contents_count);?></div>
						<div class="total"> <?php echo WC()->cart->get_cart_total(); ?>
						</div>
					</a>
	<?php
	
	$fragments['a.cart-contents'] = ob_get_clean();
	
	return $fragments;
}
